export declare class ErrorBase<T extends string> extends Error {
    name: T;
    message: string;
    cause?: any;
    constructor({ name, message, cause, }: {
        name: T;
        message: string;
        cause?: any;
    });
}
export type ClientErrorName = 'bech32HrpMismatch' | 'blake2b256' | 'block' | 'crypto' | 'inputAddressNotFound' | 'invalidAmount' | 'invalidMnemonic' | 'json' | 'missingParameter' | 'node' | 'noOutput' | 'placeholderSecretManager' | 'poisonError' | 'prefixHex' | 'quorumPoolSizeError' | 'quorumThresholdError' | 'secretManagerMismatch' | 'healthyNodePoolEmpty' | 'taggedData' | 'transactionAcceptance' | 'taskJoin' | 'timeNotSynced' | 'transactionSemantic' | 'unpack' | 'urlAuth' | 'url' | 'urlValidation' | 'inputSelection' | 'missingBip32Chain' | 'unexpectedBlockBodyKind' | 'missingTransactionPayload' | 'expirationDeadzone' | 'participation' | 'ledger' | 'mqtt' | 'stronghold';
export declare class ClientError extends ErrorBase<ClientErrorName> {
}
export type WalletErrorName = 'backup' | 'block' | 'burningOrMeltingFailed' | 'client' | 'bipPathMismatch' | 'crypto' | 'customInput' | 'insufficientFunds' | 'invalidEventType' | 'invalidMnemonic' | 'invalidOutputKind' | 'invalidVotingPower' | 'io' | 'json' | 'migration' | 'mintingFailed' | 'missingBipPath' | 'missingParameter' | 'nftNotFoundInUnspentOutputs' | 'noOutputsToConsolidate' | 'other' | 'participation' | 'storage' | 'storageIsEncrypted' | 'taskJoin' | 'transactionNotFound' | 'voting' | 'walletAddressMismatch' | 'nonEd25519Address' | 'implicitAccountNotFound' | 'accountNotFound';
export declare class WalletError extends ErrorBase<WalletErrorName> {
}
export declare class BlockError extends ErrorBase<'block'> {
    constructor(message: string);
}
export declare class PrefixHexError extends ErrorBase<'prefixHex'> {
    constructor(message: string);
}
export declare class SerdeJsonError extends ErrorBase<'serdeJson'> {
    constructor(message: string);
}
export declare class UnpackError extends ErrorBase<'unpack'> {
    constructor(message: string);
}
export type Errors = BlockError | ClientError | WalletError | PrefixHexError | SerdeJsonError | UnpackError;
